@@ -1,4 +1,4 @@
-km<-function(r,d,var = "O",conf=.95,ylab="Pr(survivorship from 1st age class)",age.seq=seq(1,length(r)),xlab="Age class", ...){
+km<-function(r,d,var = "O",conf=.95,age.seq=seq(1,length(r)),ylab="Pr(survivorship from 1st age class)",xlab="Age class", ...){
 step <- (1-(d/r))## Eq.1
 s.hat<-matrix(nrow=length(r),ncol=1)
 for(i in 1:length(r)){
